@@ -6,6 +6,7 @@ use warnings;
 
 sub mangle_ident {
     my $s = shift;
+    Carp::confess unless defined $s;
     $s =~ s/ ([^a-zA-Z0-9_:]) / '_'.ord($1).'_' /xge;
     return $s;
 }
@@ -17,6 +18,10 @@ sub mangle_var {
     # perl6 => perl5 variables
     return '%::ENV'    if $s eq '%*ENV';  
     return '$^O'       if $s eq '$*OS';  
+    return '$$'        if $s eq '$*PID';  
+    return '$0'        if $s eq '$*EXECUTABLE_NAME';  
+
+    return '__FILE__'  if $s eq '$?FILE';
     
     # special variables
     return '$::_V6ERR_'   if $s eq '$!';
